@@ -5,14 +5,14 @@
 #define INCLUDED_OCIO_OPENCOLORABI_H
 
 // Makefile configuration options
-#define OCIO_NAMESPACE OpenColorIO_v2_1
+#define OCIO_NAMESPACE OpenColorIO_v2_2
 
-#define OCIO_VERSION_STR        "2.1.1"
+#define OCIO_VERSION_STR        "2.2.1"
 #define OCIO_VERSION_STATUS_STR ""
-#define OCIO_VERSION_FULL_STR   "2.1.1"
+#define OCIO_VERSION_FULL_STR   "2.2.1"
 
 // Deprecated synonym for downstream projects that expect the 1.x name
-#define OCIO_VERSION            "2.1.1"
+#define OCIO_VERSION            "2.2.1"
 
 /* Version as a single 4-byte hex number, e.g. 0x01050200 == 1.5.2
    Use this for numeric comparisons, e.g. #if OCIO_VERSION_HEX >= ... 
@@ -20,11 +20,11 @@
    this will reflect the original API version number.
    */
 #define OCIO_VERSION_HEX ((2 << 24) | \
-                          (1 << 16) | \
+                          (2 << 16) | \
                           (1 <<  8))
 
 #define OCIO_VERSION_MAJOR 2
-#define OCIO_VERSION_MINOR 1
+#define OCIO_VERSION_MINOR 2
 
 
 // Highlight deprecated methods or classes.
@@ -47,7 +47,7 @@
 
 // If supported, define OCIOEXPORT, OCIOHIDDEN
 // (used to choose which symbols to export from OpenColorIO)
-#if defined(_WIN32)
+#if defined(_WIN32) || defined(__CYGWIN__)
     // Windows requires you to export from the main library and then import in any others
     // only when compiling a dynamic library (i.e. DLL)
     #ifndef OpenColorIO_SKIP_IMPORTS
